@@ -15,6 +15,7 @@
 
 #include <aws/http/connection.h>
 #include <aws/http/connection_manager.h>
+#include <aws/http/proxy.h>
 #include <aws/http/request_response.h>
 
 #include <aws/auth/private/credentials_utils.h>
@@ -57,6 +58,8 @@ struct aws_mock_sts_tester {
 
     bool fail_connection;
 
+    int provider_shutdown_callback_count;
+
     struct aws_event_loop_group *el_group;
 
     struct aws_host_resolver *resolver;
@@ -64,6 +67,8 @@ struct aws_mock_sts_tester {
     struct aws_client_bootstrap *bootstrap;
 
     struct aws_tls_ctx *tls_ctx;
+
+    struct proxy_env_var_settings *proxy_config;
 };
 
 static struct aws_mock_sts_tester s_tester;
@@ -78,22 +83,53 @@ static void s_on_connection_manager_shutdown_complete(void *user_data) {
     aws_condition_variable_notify_one(&s_tester.signal);
 }
 
-static bool s_has_tester_received_shutdown_callback(void *user_data) {
+static bool s_has_tester_received_connection_manager_shutdown_callback(void *user_data) {
     (void)user_data;
 
     return s_tester.mocked_connection_manager_shutdown_callback_count ==
            s_tester.expected_connection_manager_shutdown_callback_count;
 }
 
+static void s_aws_wait_for_connection_manager_shutdown_callback(void) {
+    aws_mutex_lock(&s_tester.lock);
+    aws_condition_variable_wait_pred(
+        &s_tester.signal, &s_tester.lock, s_has_tester_received_connection_manager_shutdown_callback, NULL);
+    aws_mutex_unlock(&s_tester.lock);
+}
+
+static void s_on_provider_shutdown(void *user_data) {
+    (void)user_data;
+
+    aws_mutex_lock(&s_tester.lock);
+    s_tester.provider_shutdown_callback_count++;
+    aws_mutex_unlock(&s_tester.lock);
+
+    aws_condition_variable_notify_one(&s_tester.signal);
+}
+
+static bool s_has_tester_received_provider_shutdown_callback(void *user_data) {
+    (void)user_data;
+
+    return s_tester.provider_shutdown_callback_count;
+}
+
 static void s_aws_wait_for_provider_shutdown_callback(void) {
     aws_mutex_lock(&s_tester.lock);
-    aws_condition_variable_wait_pred(&s_tester.signal, &s_tester.lock, s_has_tester_received_shutdown_callback, NULL);
+    aws_condition_variable_wait_pred(
+        &s_tester.signal, &s_tester.lock, s_has_tester_received_provider_shutdown_callback, NULL);
     aws_mutex_unlock(&s_tester.lock);
 }
 
 static struct aws_http_connection_manager *s_aws_http_connection_manager_new_mock(
     struct aws_allocator *allocator,
     const struct aws_http_connection_manager_options *options) {
+
+    if (s_tester.proxy_config != NULL) {
+        AWS_FATAL_ASSERT(options->proxy_ev_settings->env_var_type == s_tester.proxy_config->env_var_type);
+        AWS_FATAL_ASSERT(options->proxy_ev_settings->connection_type == s_tester.proxy_config->connection_type);
+        AWS_FATAL_ASSERT(options->proxy_ev_settings->tls_options == s_tester.proxy_config->tls_options);
+    }
+
     /* copy the shutdown callback */
     struct aws_shutdown_callback_options *shutdown_callback =
         aws_mem_calloc(allocator, 1, sizeof(struct aws_shutdown_callback_options));
@@ -400,9 +436,10 @@ static struct aws_byte_cursor s_success_creds_doc =
                                           "             <SecretAccessKey>secretKeyResp</SecretAccessKey>\n"
                                           "             <SessionToken>sessionTokenResp</SessionToken>\n"
                                           "         </Credentials>\n"
-                                          "         <AssumeRoleUser>\n"
-                                          "             ... a bunch of other stuff we don't care about\n"
-                                          "         </AssumeRoleUser>\n"
+                                          "         <AssumedRoleUser>\n"
+                                          "             <AssumedRoleId>assumeRoleIdResp</AssumedRoleId>\n"
+                                          "             <Arn>arn:aws:sts::123456789012:assumed-role</Arn>\n"
+                                          "         </AssumedRoleUser>\n"
                                           "         ... more stuff we don't care about\n"
                                           "      </AssumeRoleResult>\n"
                                           "</AssumeRoleResponse>");
@@ -422,12 +459,14 @@ static struct aws_byte_cursor s_expected_payload_with_external_id =
 AWS_STATIC_STRING_FROM_LITERAL(s_access_key_id_response, "accessKeyIdResp");
 AWS_STATIC_STRING_FROM_LITERAL(s_secret_access_key_response, "secretKeyResp");
 AWS_STATIC_STRING_FROM_LITERAL(s_session_token_response, "sessionTokenResp");
+AWS_STATIC_STRING_FROM_LITERAL(s_account_id_response, "123456789012");
 
 static int s_verify_credentials(struct aws_credentials *credentials) {
     ASSERT_NOT_NULL(credentials);
     ASSERT_CURSOR_VALUE_STRING_EQUALS(aws_credentials_get_access_key_id(credentials), s_access_key_id_response);
     ASSERT_CURSOR_VALUE_STRING_EQUALS(aws_credentials_get_secret_access_key(credentials), s_secret_access_key_response);
     ASSERT_CURSOR_VALUE_STRING_EQUALS(aws_credentials_get_session_token(credentials), s_session_token_response);
+    ASSERT_CURSOR_VALUE_STRING_EQUALS(aws_credentials_get_account_id(credentials), s_account_id_response);
 
     return AWS_OP_SUCCESS;
 }
@@ -508,7 +547,7 @@ static int s_credentials_provider_sts_direct_config_succeeds_fn(struct aws_alloc
         s_tester.mocked_requests[0].body.len);
 
     aws_credentials_provider_release(sts_provider);
-    s_aws_wait_for_provider_shutdown_callback();
+    s_aws_wait_for_connection_manager_shutdown_callback();
     aws_credentials_provider_release(static_provider);
     ASSERT_SUCCESS(s_aws_sts_tester_cleanup());
 
@@ -561,7 +600,7 @@ static int s_credentials_provider_sts_direct_config_with_external_id_succeeds_fn
         s_tester.mocked_requests[0].body.len);
 
     aws_credentials_provider_release(sts_provider);
-    s_aws_wait_for_provider_shutdown_callback();
+    s_aws_wait_for_connection_manager_shutdown_callback();
     aws_credentials_provider_release(static_provider);
     ASSERT_SUCCESS(s_aws_sts_tester_cleanup());
 
@@ -658,7 +697,7 @@ static int s_credentials_provider_sts_direct_config_with_region_succeeds_fn(
         s_tester.mocked_requests[0].body.len);
 
     aws_credentials_provider_release(sts_provider);
-    s_aws_wait_for_provider_shutdown_callback();
+    s_aws_wait_for_connection_manager_shutdown_callback();
     aws_credentials_provider_release(static_provider);
     ASSERT_SUCCESS(s_aws_sts_tester_cleanup());
 
@@ -741,7 +780,7 @@ static int s_credentials_provider_sts_direct_config_with_default_region_succeeds
         s_tester.mocked_requests[0].body.len);
 
     aws_credentials_provider_release(sts_provider);
-    s_aws_wait_for_provider_shutdown_callback();
+    s_aws_wait_for_connection_manager_shutdown_callback();
     aws_credentials_provider_release(static_provider);
     ASSERT_SUCCESS(s_aws_sts_tester_cleanup());
 
@@ -829,7 +868,7 @@ static int s_credentials_provider_sts_direct_config_with_region_from_config_succ
         s_tester.mocked_requests[0].body.len);
 
     aws_credentials_provider_release(sts_provider);
-    s_aws_wait_for_provider_shutdown_callback();
+    s_aws_wait_for_connection_manager_shutdown_callback();
     aws_credentials_provider_release(static_provider);
     aws_file_delete(config_file_str);
     aws_string_destroy(config_file_str);
@@ -915,7 +954,7 @@ static int s_credentials_provider_sts_direct_config_succeeds_after_retry_fn(
         s_tester.mocked_requests[0].body.len);
 
     aws_credentials_provider_release(sts_provider);
-    s_aws_wait_for_provider_shutdown_callback();
+    s_aws_wait_for_connection_manager_shutdown_callback();
     aws_credentials_provider_release(static_provider);
     ASSERT_SUCCESS(s_aws_sts_tester_cleanup());
 
@@ -999,7 +1038,7 @@ static int s_credentials_provider_sts_direct_config_invalid_doc_fn(struct aws_al
         s_tester.mocked_requests[0].body.len);
 
     aws_credentials_provider_release(sts_provider);
-    s_aws_wait_for_provider_shutdown_callback();
+    s_aws_wait_for_connection_manager_shutdown_callback();
     aws_credentials_provider_release(static_provider);
     ASSERT_SUCCESS(s_aws_sts_tester_cleanup());
 
@@ -1046,7 +1085,7 @@ static int s_credentials_provider_sts_direct_config_connection_failed_fn(struct
     ASSERT_NULL(s_tester.credentials);
 
     aws_credentials_provider_release(sts_provider);
-    s_aws_wait_for_provider_shutdown_callback();
+    s_aws_wait_for_connection_manager_shutdown_callback();
     aws_credentials_provider_release(static_provider);
     ASSERT_SUCCESS(s_aws_sts_tester_cleanup());
 
@@ -1096,7 +1135,7 @@ static int s_credentials_provider_sts_direct_config_service_fails_fn(struct aws_
     ASSERT_NULL(s_tester.credentials);
 
     aws_credentials_provider_release(sts_provider);
-    s_aws_wait_for_provider_shutdown_callback();
+    s_aws_wait_for_connection_manager_shutdown_callback();
     aws_credentials_provider_release(static_provider);
     ASSERT_SUCCESS(s_aws_sts_tester_cleanup());
 
@@ -1166,6 +1205,10 @@ static int s_credentials_provider_sts_from_profile_config_with_chain_fn(struct a
         .profile_name_override = aws_byte_cursor_from_c_str("roletest"),
         .bootstrap = s_tester.bootstrap,
         .function_table = &s_mock_function_table,
+        .shutdown_options =
+            {
+                .shutdown_callback = s_on_provider_shutdown,
+            },
     };
     int expected_num_requests = 3;
     for (int i = 0; i < expected_num_requests; i++) {
@@ -1223,7 +1266,12 @@ static int s_credentials_provider_sts_from_profile_config_with_chain_fn(struct a
     }
 
     aws_credentials_provider_release(provider);
+    s_aws_wait_for_connection_manager_shutdown_callback();
     s_aws_wait_for_provider_shutdown_callback();
+    /* There used to be a bug that triggered the shutdown callback multiple times. Sleep for a few seconds
+     * and validate that we don't trigger the shutdown callback multiple times */
+    aws_thread_current_sleep(3000000000);
+    ASSERT_INT_EQUALS(1, s_tester.provider_shutdown_callback_count);
     ASSERT_SUCCESS(s_aws_sts_tester_cleanup());
 
     return AWS_OP_SUCCESS;
@@ -1233,10 +1281,10 @@ AWS_TEST_CASE(
     s_credentials_provider_sts_from_profile_config_with_chain_fn)
 
 AWS_STATIC_STRING_FROM_LITERAL(s_ecs_creds_env_relative_uri, "AWS_CONTAINER_CREDENTIALS_RELATIVE_URI");
-static const char *s_soure_credentials_ecs_config_file = "[default]\n"
-                                                         "role_arn=arn:aws:iam::67895:role/test_role\n"
-                                                         "credential_source=EcsContainer\n"
-                                                         "role_session_name=test_session\n";
+static const char *s_source_credentials_ecs_config_file = "[default]\n"
+                                                          "role_arn=arn:aws:iam::67895:role/test_role\n"
+                                                          "credential_source=EcsContainer\n"
+                                                          "role_session_name=test_session\n";
 static struct aws_byte_cursor s_ecs_good_response = AWS_BYTE_CUR_INIT_FROM_STRING_LITERAL(
     "{\"AccessKeyId\":\"SuccessfulAccessKey\", \n  \"SecretAccessKey\":\"SuccessfulSecret\", \n  "
     "\"Token\":\"TokenSuccess\", \n \"Expiration\":\"2020-02-25T06:03:31Z\"}");
@@ -1255,9 +1303,9 @@ static int s_credentials_provider_sts_from_profile_config_with_ecs_credentials_s
     ASSERT_SUCCESS(aws_set_environment_value(s_ecs_creds_env_relative_uri, relative_uri_str));
 
     s_aws_sts_tester_init(allocator);
-    /* one for ecs provdier and one for sts provider */
+    /* one for ecs provider and one for sts provider */
     s_tester.expected_connection_manager_shutdown_callback_count = 2;
-    struct aws_string *config_contents = aws_string_new_from_c_str(allocator, s_soure_credentials_ecs_config_file);
+    struct aws_string *config_contents = aws_string_new_from_c_str(allocator, s_source_credentials_ecs_config_file);
 
     struct aws_string *config_file_str = aws_create_process_unique_file_name(allocator);
     struct aws_string *creds_file_str = aws_create_process_unique_file_name(allocator);
@@ -1331,7 +1379,7 @@ static int s_credentials_provider_sts_from_profile_config_with_ecs_credentials_s
     }
 
     aws_credentials_provider_release(provider);
-    s_aws_wait_for_provider_shutdown_callback();
+    s_aws_wait_for_connection_manager_shutdown_callback();
     aws_string_destroy(relative_uri_str);
     aws_string_destroy(config_file_str);
     aws_string_destroy(creds_file_str);
@@ -1343,24 +1391,24 @@ AWS_TEST_CASE(
     credentials_provider_sts_from_profile_config_with_ecs_credentials_source,
     s_credentials_provider_sts_from_profile_config_with_ecs_credentials_source_fn)
 
-static const char *s_soure_profile_chain_and_profile_config_file = "[default]\n"
-                                                                   "aws_access_key_id=BLAHBLAH\n"
-                                                                   "aws_secret_access_key=BLAHBLAHBLAH\n"
-                                                                   "\n"
-                                                                   "[roletest]\n"
-                                                                   "role_arn=arn:aws:iam::67895:role/test_role\n"
-                                                                   "source_profile=roletest2\n"
-                                                                   "role_session_name=test_session\n"
-                                                                   "[roletest2]\n"
-                                                                   "role_arn=arn:aws:iam::67896:role/test_role\n"
-                                                                   "source_profile=roletest3\n"
-                                                                   "role_session_name=test_session2\n"
-                                                                   "[roletest3]\n"
-                                                                   "role_arn=arn:aws:iam::67897:role/test_role\n"
-                                                                   "source_profile=default\n"
-                                                                   "role_session_name=test_session3\n"
-                                                                   "aws_access_key_id = BLAH\n"
-                                                                   "aws_secret_access_key = BLAHBLAH\n";
+static const char *s_source_profile_chain_and_profile_config_file = "[default]\n"
+                                                                    "aws_access_key_id=BLAHBLAH\n"
+                                                                    "aws_secret_access_key=BLAHBLAHBLAH\n"
+                                                                    "\n"
+                                                                    "[roletest]\n"
+                                                                    "role_arn=arn:aws:iam::67895:role/test_role\n"
+                                                                    "source_profile=roletest2\n"
+                                                                    "role_session_name=test_session\n"
+                                                                    "[roletest2]\n"
+                                                                    "role_arn=arn:aws:iam::67896:role/test_role\n"
+                                                                    "source_profile=roletest3\n"
+                                                                    "role_session_name=test_session2\n"
+                                                                    "[roletest3]\n"
+                                                                    "role_arn=arn:aws:iam::67897:role/test_role\n"
+                                                                    "source_profile=default\n"
+                                                                    "role_session_name=test_session3\n"
+                                                                    "aws_access_key_id = BLAH\n"
+                                                                    "aws_secret_access_key = BLAHBLAH\n";
 static int s_credentials_provider_sts_from_profile_config_with_chain_and_profile_creds_fn(
     struct aws_allocator *allocator,
     void *ctx) {
@@ -1373,7 +1421,7 @@ static int s_credentials_provider_sts_from_profile_config_with_chain_and_profile
     s_aws_sts_tester_init(allocator);
     s_tester.expected_connection_manager_shutdown_callback_count = 2;
     struct aws_string *config_contents =
-        aws_string_new_from_c_str(allocator, s_soure_profile_chain_and_profile_config_file);
+        aws_string_new_from_c_str(allocator, s_source_profile_chain_and_profile_config_file);
 
     struct aws_string *config_file_str = aws_create_process_unique_file_name(allocator);
     struct aws_string *creds_file_str = aws_create_process_unique_file_name(allocator);
@@ -1443,7 +1491,7 @@ static int s_credentials_provider_sts_from_profile_config_with_chain_and_profile
     }
 
     aws_credentials_provider_release(provider);
-    s_aws_wait_for_provider_shutdown_callback();
+    s_aws_wait_for_connection_manager_shutdown_callback();
     ASSERT_SUCCESS(s_aws_sts_tester_cleanup());
 
     return AWS_OP_SUCCESS;
@@ -1452,7 +1500,7 @@ AWS_TEST_CASE(
     credentials_provider_sts_from_profile_config_with_chain_and_profile_creds,
     s_credentials_provider_sts_from_profile_config_with_chain_and_profile_creds_fn)
 
-static const char *s_soure_profile_chain_and_partial_profile_config_file =
+static const char *s_source_profile_chain_and_partial_profile_config_file =
     "[default]\n"
     "aws_access_key_id=BLAHBLAH\n"
     "aws_secret_access_key=BLAHBLAHBLAH\n"
@@ -1482,7 +1530,7 @@ static int s_credentials_provider_sts_from_profile_config_with_chain_and_partial
     s_aws_sts_tester_init(allocator);
     s_tester.expected_connection_manager_shutdown_callback_count = 2;
     struct aws_string *config_contents =
-        aws_string_new_from_c_str(allocator, s_soure_profile_chain_and_partial_profile_config_file);
+        aws_string_new_from_c_str(allocator, s_source_profile_chain_and_partial_profile_config_file);
 
     struct aws_string *config_file_str = aws_create_process_unique_file_name(allocator);
     struct aws_string *creds_file_str = aws_create_process_unique_file_name(allocator);
@@ -1514,7 +1562,7 @@ static int s_credentials_provider_sts_from_profile_config_with_chain_and_partial
     ASSERT_NULL(s_tester.credentials);
     ASSERT_INT_EQUALS(s_tester.error_code, AWS_AUTH_SIGNING_NO_CREDENTIALS);
     aws_credentials_provider_release(provider);
-    s_aws_wait_for_provider_shutdown_callback();
+    s_aws_wait_for_connection_manager_shutdown_callback();
     ASSERT_SUCCESS(s_aws_sts_tester_cleanup());
 
     return AWS_OP_SUCCESS;
@@ -1523,16 +1571,16 @@ AWS_TEST_CASE(
     credentials_provider_sts_from_profile_config_with_chain_and_partial_profile_creds,
     s_credentials_provider_sts_from_profile_config_with_chain_and_partial_profile_creds_fn)
 
-static const char *s_soure_profile_self_assume_role_config_file = "[default]\n"
-                                                                  "aws_access_key_id=BLAHBLAH\n"
-                                                                  "aws_secret_access_key=BLAHBLAHBLAH\n"
-                                                                  "\n"
-                                                                  "[roletest]\n"
-                                                                  "role_arn=arn:aws:iam::67895:role/test_role\n"
-                                                                  "source_profile=roletest\n"
-                                                                  "role_session_name=test_session\n"
-                                                                  "aws_access_key_id = BLAH\n"
-                                                                  "aws_secret_access_key = BLAHBLAH\n";
+static const char *s_source_profile_self_assume_role_config_file = "[default]\n"
+                                                                   "aws_access_key_id=BLAHBLAH\n"
+                                                                   "aws_secret_access_key=BLAHBLAHBLAH\n"
+                                                                   "\n"
+                                                                   "[roletest]\n"
+                                                                   "role_arn=arn:aws:iam::67895:role/test_role\n"
+                                                                   "source_profile=roletest\n"
+                                                                   "role_session_name=test_session\n"
+                                                                   "aws_access_key_id = BLAH\n"
+                                                                   "aws_secret_access_key = BLAHBLAH\n";
 static int s_credentials_provider_sts_from_self_referencing_profile_fn(struct aws_allocator *allocator, void *ctx) {
     (void)ctx;
 
@@ -1542,7 +1590,7 @@ static int s_credentials_provider_sts_from_self_referencing_profile_fn(struct aw
 
     s_aws_sts_tester_init(allocator);
     struct aws_string *config_contents =
-        aws_string_new_from_c_str(allocator, s_soure_profile_self_assume_role_config_file);
+        aws_string_new_from_c_str(allocator, s_source_profile_self_assume_role_config_file);
 
     struct aws_string *config_file_str = aws_create_process_unique_file_name(allocator);
     struct aws_string *creds_file_str = aws_create_process_unique_file_name(allocator);
@@ -1607,7 +1655,7 @@ static int s_credentials_provider_sts_from_self_referencing_profile_fn(struct aw
     }
 
     aws_credentials_provider_release(provider);
-    s_aws_wait_for_provider_shutdown_callback();
+    s_aws_wait_for_connection_manager_shutdown_callback();
     ASSERT_SUCCESS(s_aws_sts_tester_cleanup());
 
     return AWS_OP_SUCCESS;
@@ -1616,22 +1664,22 @@ AWS_TEST_CASE(
     credentials_provider_sts_from_self_referencing_profile,
     s_credentials_provider_sts_from_self_referencing_profile_fn)
 
-static const char *s_soure_profile_chain_cycle_config_file = "[default]\n"
-                                                             "aws_access_key_id=BLAHBLAH\n"
-                                                             "aws_secret_access_key=BLAHBLAHBLAH\n"
-                                                             "\n"
-                                                             "[roletest]\n"
-                                                             "role_arn=arn:aws:iam::67895:role/test_role\n"
-                                                             "source_profile=roletest2\n"
-                                                             "role_session_name=test_session\n"
-                                                             "[roletest2]\n"
-                                                             "role_arn=arn:aws:iam::67896:role/test_role\n"
-                                                             "source_profile=roletest3\n"
-                                                             "role_session_name=test_session2\n"
-                                                             "[roletest3]\n"
-                                                             "role_arn=arn:aws:iam::67897:role/test_role\n"
-                                                             "source_profile=roletest2\n"
-                                                             "role_session_name=test_session3\n";
+static const char *s_source_profile_chain_cycle_config_file = "[default]\n"
+                                                              "aws_access_key_id=BLAHBLAH\n"
+                                                              "aws_secret_access_key=BLAHBLAHBLAH\n"
+                                                              "\n"
+                                                              "[roletest]\n"
+                                                              "role_arn=arn:aws:iam::67895:role/test_role\n"
+                                                              "source_profile=roletest2\n"
+                                                              "role_session_name=test_session\n"
+                                                              "[roletest2]\n"
+                                                              "role_arn=arn:aws:iam::67896:role/test_role\n"
+                                                              "source_profile=roletest3\n"
+                                                              "role_session_name=test_session2\n"
+                                                              "[roletest3]\n"
+                                                              "role_arn=arn:aws:iam::67897:role/test_role\n"
+                                                              "source_profile=roletest2\n"
+                                                              "role_session_name=test_session3\n";
 
 static int s_credentials_provider_sts_from_profile_config_with_chain_cycle_fn(
     struct aws_allocator *allocator,
@@ -1644,7 +1692,7 @@ static int s_credentials_provider_sts_from_profile_config_with_chain_cycle_fn(
 
     s_aws_sts_tester_init(allocator);
 
-    struct aws_string *config_contents = aws_string_new_from_c_str(allocator, s_soure_profile_chain_cycle_config_file);
+    struct aws_string *config_contents = aws_string_new_from_c_str(allocator, s_source_profile_chain_cycle_config_file);
 
     struct aws_string *config_file_str = aws_create_process_unique_file_name(allocator);
     struct aws_string *creds_file_str = aws_create_process_unique_file_name(allocator);
@@ -1677,7 +1725,7 @@ AWS_TEST_CASE(
     credentials_provider_sts_from_profile_config_with_chain_cycle,
     s_credentials_provider_sts_from_profile_config_with_chain_cycle_fn)
 
-static const char *s_soure_profile_chain_cycle_and_static_creds_config_file =
+static const char *s_source_profile_chain_cycle_and_static_creds_config_file =
     "[roletest]\n"
     "role_arn=arn:aws:iam::67895:role/test_role\n"
     "source_profile=roletest2\n"
@@ -1705,7 +1753,7 @@ static int s_credentials_provider_sts_from_profile_config_with_chain_cycle_and_p
     s_aws_sts_tester_init(allocator);
 
     struct aws_string *config_contents =
-        aws_string_new_from_c_str(allocator, s_soure_profile_chain_cycle_and_static_creds_config_file);
+        aws_string_new_from_c_str(allocator, s_source_profile_chain_cycle_and_static_creds_config_file);
 
     struct aws_string *config_file_str = aws_create_process_unique_file_name(allocator);
     struct aws_string *creds_file_str = aws_create_process_unique_file_name(allocator);
@@ -1813,7 +1861,7 @@ static int s_credentials_provider_sts_from_profile_config_succeeds(
         s_tester.mocked_requests[0].body.len);
 
     aws_credentials_provider_release(provider);
-    s_aws_wait_for_provider_shutdown_callback();
+    s_aws_wait_for_connection_manager_shutdown_callback();
     ASSERT_SUCCESS(s_aws_sts_tester_cleanup());
 
     return AWS_OP_SUCCESS;
@@ -1885,7 +1933,7 @@ static int s_credentials_provider_sts_from_profile_config_with_external_id_fn(
         s_tester.mocked_requests[0].body.len);
 
     aws_credentials_provider_release(provider);
-    s_aws_wait_for_provider_shutdown_callback();
+    s_aws_wait_for_connection_manager_shutdown_callback();
     ASSERT_SUCCESS(s_aws_sts_tester_cleanup());
 
     return AWS_OP_SUCCESS;
@@ -1982,7 +2030,7 @@ static int s_credentials_provider_sts_from_profile_config_environment_succeeds_f
         s_tester.mocked_requests[0].body.len);
 
     aws_credentials_provider_release(provider);
-    s_aws_wait_for_provider_shutdown_callback();
+    s_aws_wait_for_connection_manager_shutdown_callback();
 
     ASSERT_SUCCESS(s_aws_sts_tester_cleanup());
 
@@ -2105,7 +2153,7 @@ static int s_credentials_provider_sts_cache_expiration_conflict(struct aws_alloc
 
     aws_credentials_provider_release(cached_provider);
     aws_credentials_provider_release(sts_provider);
-    s_aws_wait_for_provider_shutdown_callback();
+    s_aws_wait_for_connection_manager_shutdown_callback();
     aws_credentials_provider_release(static_provider);
 
     ASSERT_SUCCESS(s_aws_sts_tester_cleanup());
@@ -2114,3 +2162,55 @@ static int s_credentials_provider_sts_cache_expiration_conflict(struct aws_alloc
 }
 
 AWS_TEST_CASE(credentials_provider_sts_cache_expiration_conflict, s_credentials_provider_sts_cache_expiration_conflict)
+
+static int s_credentials_provider_sts_proxy_routing_enabled_test(struct aws_allocator *allocator, void *ctx) {
+    (void)ctx;
+
+    s_aws_sts_tester_init(allocator);
+
+    struct proxy_env_var_settings proxy_config = {
+        .env_var_type = AWS_HPEV_ENABLE,
+    };
+
+    s_tester.proxy_config = &proxy_config;
+    s_tester.fail_connection = true;
+
+    struct aws_credentials_provider_static_options static_options = {
+        .access_key_id = s_access_key_cur,
+        .secret_access_key = s_secret_key_cur,
+        .session_token = s_session_token_cur,
+    };
+    struct aws_credentials_provider *static_provider = aws_credentials_provider_new_static(allocator, &static_options);
+
+    struct aws_credentials_provider_sts_options options = {
+        .creds_provider = static_provider,
+        .bootstrap = s_tester.bootstrap,
+        .tls_ctx = s_tester.tls_ctx,
+        .role_arn = s_role_arn_cur,
+        .session_name = s_session_name_cur,
+        .duration_seconds = 0,
+        .function_table = &s_mock_function_table,
+        .system_clock_fn = mock_aws_get_system_time,
+        .proxy_ev_settings = &proxy_config,
+    };
+
+    mock_aws_set_system_time(0);
+
+    struct aws_credentials_provider *sts_provider = aws_credentials_provider_new_sts(allocator, &options);
+
+    aws_credentials_provider_get_credentials(sts_provider, s_get_credentials_callback, NULL);
+
+    s_aws_wait_for_credentials_result();
+
+    ASSERT_TRUE(s_tester.credentials == NULL);
+
+    aws_credentials_provider_release(sts_provider);
+    s_aws_wait_for_connection_manager_shutdown_callback();
+    aws_credentials_provider_release(static_provider);
+    ASSERT_SUCCESS(s_aws_sts_tester_cleanup());
+
+    return AWS_OP_SUCCESS;
+}
+AWS_TEST_CASE(
+    credentials_provider_sts_proxy_routing_enabled_test,
+    s_credentials_provider_sts_proxy_routing_enabled_test)
